'use strict';

/*
* No need to customize. All required changes go into dataAccess.js
*/

const dataAccess = require('./data/dataAccess');

module.exports = {
  metadata: () => ({
    name: 'cxs.QueryOrders',
    properties: {
      userId: { required: true, type: 'string' },
      variable: { required: true, type: 'string' },
    },
    supportedActions: ['noOrdersFound', 'ordersFound']
  }),
  invoke: (context, done) => {
    // Retrieve the value of the 'human' component property.
    const { userId } = context.properties();
    
    //get name of variable that should receive order array
    const { variable } = context.properties();

    let orders = dataAccess.queryOrders(userId);

    //navigate dialog flow based on whether or not an order was found
    if(orders == null || orders.length == 0){
      context.transition("noOrdersFound");
    }
    else{
      context.transition("ordersFound");
    }

    //set order array to the variable passed as an argument
    context.variable(variable,orders);
    //continue to next dialog flow state without user interaction
    context.keepTurn(true);
    done();  
  }
};
