/*
 * This file needs to be changed for a custom implementation that does not read data from
 * a JSON file but queries data from a remote REST service. To query a REST service you can 
 * use your favorite http client package. However, the node fetch API is pre-installed with 
 * the bots-node-sdk. Documentation can be found at https://www.npmjs.com/package/node-fetch
 */

/*
 * Uncomment the next line and comment out the line after to use REST calls
 */
// const fetch = require("node-fetch");
const data = require('./data.json');

module.exports = {

    /*
    * orders are returned as an array of objects, where each object has a format of {orderId: 123, 
    * orderItem: "Legendary Treadmill", image: "https://..."}
    */
    queryOrders: (userId) => {
        /*
         * the row below reads from the data.json file. In a real implementation you 
         * would query a REST service, which means that t he line below would need to
         * be changed to a node fetch call
         */
        const dummy_user = 'user@example.com'; // for simplicity in demos we'll just assume all users are for user@example.com
        let orders = data[dummy_user];  // You can use userId if you have actual email addresses e.g. data[userId];

        /*
        *  The order overview is a limited view to all orders. The sample does not implement
        *  filtering orders. 
        */
        let orderOverview = [];

        if (orders != null) {
            orders.forEach(element => {
                let item = {};
                item.orderId = element.orderId;
                item.orderItem = element.item;
                item.image = element.image;
                orderOverview.push(item);
            });
        }
        return orderOverview;
    },

    /*
     * This function queries a order by its Id and the user Id. The query returns 
     * a data object in the form of {orderId: 123, orderItem: "Legendary Treadmill", 
     * image: "https://...", price: "1200 USD", updated: "March 21 2021", status: "open"}
     */
    checkStatus: (userId, orderId) => {
        /*
          * the row below reads from the data.json file. In a real implementation you 
          * would query a REST service, which means that t he line below would need to
          * be changed to a node fetch call
          */
        const dummy_user = 'user@example.com' // for simplicity in demos we'll just assume all users are for user@example.com
        let orders = data[dummy_user]  // You can use userId if you have actual email addresses e.g. data[userId];
        let order = null;

        if (orders != null) {
            orders.forEach(element => {
                //find a match
                if (element.orderId == orderId) {
                    order = {};
                    order.orderId = element.orderId;
                    order.orderItem = element.item;
                    order.image = element.image;
                    order.price = element.price;
                    order.updated = element.updated;
                    order.status = element.status;
                    return order;
                }               
            });
        }
        //case of no order found
        return order;
    }
};